@@ -118,7 +118,13 @@ class CodeArtifact(
         :stability: deprecated
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CodeArtifact.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id: builtins.str,
+                props: "IDomainProps",
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
@@ -171,7 +177,13 @@ class Domain(
         :param props: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Domain.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id: builtins.str,
+                props: "IDomainProps",
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
@@ -492,7 +504,21 @@ class Repository(
         :param upstreams: A list of upstream repositories to associate with the repository. The order of the upstream repositories in the list determines their priority order when AWS CodeArtifact looks for a requested package version. For more information, see `Working with upstream repositories <https://docs.aws.amazon.com/codeartifact/latest/ug/repos-upstream.html>`_ .
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Repository.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id: builtins.str,
+                *,
+                domain_name: builtins.str,
+                repository_name: builtins.str,
+                description: typing.Optional[builtins.str] = None,
+                domain_owner: typing.Optional[builtins.str] = None,
+                external_connections: typing.Optional[typing.Sequence[builtins.str]] = None,
+                permissions_policy_document: typing.Any = None,
+                tags: typing.Optional[typing.Sequence[typing.Union[aws_cdk.CfnTag, typing.Dict[str, typing.Any]]]] = None,
+                upstreams: typing.Optional[typing.Sequence[builtins.str]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = aws_cdk.aws_codeartifact.CfnRepositoryProps(
